@@ -1,8 +1,6 @@
 #' Get 3h forecast data.
 #'
 #' @inheritParams get_current
-# @param city city name or id
-# @param ... see owm api documentation
 #'
 #' @return list
 #' @export
@@ -13,7 +11,9 @@
 #'    get_forecast("London", cnt = 10)
 #'    get_forecast(lat = -22.90278, lon = -22.90278, cnt = 3, units = "metric")
 #' }
-get_forecast <- function(city = NA, ...){
+get_forecast <- function(city = NA, ...) {
   get <- owmr_wrap_get("forecast")
-  get(city, ...) %>% owmr_parse()
+  get(city, ...) %>%
+    owmr_parse() %>%
+    owmr_class("owmr_forecast")
 }
